schemetools.Scheme
==================

.. abjad-lineage:: abjad.tools.schemetools.Scheme.Scheme.Scheme

.. autoclass:: abjad.tools.schemetools.Scheme.Scheme.Scheme
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.schemetools.Scheme.Scheme.Scheme.force_quotes
   :noindex:

.. autoattribute:: abjad.tools.schemetools.Scheme.Scheme.Scheme.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.schemetools.Scheme.Scheme.Scheme.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__eq__
   :noindex:

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__ge__
   :noindex:

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__gt__
   :noindex:

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__le__
   :noindex:

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__lt__
   :noindex:

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__ne__
   :noindex:

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__repr__
   :noindex:

.. automethod:: abjad.tools.schemetools.Scheme.Scheme.Scheme.__str__
   :noindex:
